hyperspy\.tests\.axes package
=============================

Submodules
----------

hyperspy\.tests\.axes\.test\_axes\_manager module
-------------------------------------------------

.. automodule:: hyperspy.tests.axes.test_axes_manager
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.axes\.test\_data\_axis module
----------------------------------------------

.. automodule:: hyperspy.tests.axes.test_data_axis
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.axes
    :members:
    :undoc-members:
    :show-inheritance:
